# Changelog

## [3.3.5a1](https://github.com/OpenVoiceOS/OVOS-workshop/tree/3.3.5a1) (2025-01-30)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/3.3.4...3.3.5a1)

**Merged pull requests:**

- fix:voc\_match [\#327](https://github.com/OpenVoiceOS/OVOS-workshop/pull/327) ([JarbasAl](https://github.com/JarbasAl))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
